@@ -66,18 +66,27 @@
 ##'   bdh("SPY US Equity", c("PX_LAST", "VOLUME"),
 ##'       start.date=Sys.Date()-31*6, options=opt)
 ##'
+##'   ## example for non-date start
+##'   bdh("SPY US Equity", c("PX_LAST", "VOLUME"),
+##'       start.date="-6CM", options=opt)
+##'
 ##'   ## example for options and overrides
 ##'   opt <- c("periodicitySelection" = "QUARTERLY")
 ##'   ovrd <- c("BEST_FPERIOD_OVERRIDE"="1GQ")
 ##'   bdh("IBM US Equity", "BEST_SALES", start.date=Sys.Date()-365.25*4,
 ##'       options=opt, overrides=ovrd)
+##'
+##'   ## example for returnRelativeDate option
+##'   opt <- c(periodicitySelection="YEARLY", periodicityAdjustment="FISCAL", returnRelativeDate=TRUE)
+##'   bdh("GLB ID Equity", "CUR_MKT_CAP", as.Date("1997-12-31"), as.Date("2017-12-31"), options=opt)
 ##' }
 bdh <- function(securities, fields, start.date, end.date=NULL,
                 include.non.trading.days=FALSE, options=NULL, overrides=NULL,
                 verbose=FALSE, identity=NULL, con=defaultConnection(),
                 int.as.double=getOption("blpIntAsDouble", FALSE)) {
-    if (!class(start.date) == "Date") stop("start.date must be a Date object", call.=FALSE)
-    start.date <- format(start.date, format="%Y%m%d")
+    if (class(start.date) == "Date") {
+        start.date <- format(start.date, format="%Y%m%d")
+    }
     if (!is.null(end.date)) {
         end.date <- format(end.date, format="%Y%m%d")
     }
