@@ -21,14 +21,17 @@
 ##' This function authenticates against the the Bloomberg API
 ##'
 ##' @title Authenticate Bloomberg API access
-##' @param uuid A character variable with a unique user id token
+##' @param uuid A character variable with a unique user id token. If this
+##' is missing the function will attempt to connect to bpipe using the connection. It
+##' is assumed that an app_name was set. See blpConnect() for app_name information
 ##' @param host A character variable with a hostname, defaults to 'localhost'
 ##' @param ip.address An optional character variable with an IP address
 ##' @param con A connection object as created by a \code{blpConnect}
-##' call, and retrieved via the internal function
+##' call, and retrieved via the internal function. This is the only required
+##' argument to authenticate a bpipe connection with a appName.
 ##' \code{defaultConnection}.
-##' @return The returned object should be passed to subsequent data 
-##' calls via bdp(), bds(), etc.  
+##' @return The returned object should be passed to subsequent data
+##' calls via bdp(), bds(), etc.
 ##' @author Whit Armstrong and Dirk Eddelbuettel
 ##' @examples
 ##' \dontrun{
@@ -38,14 +41,17 @@
 ##' }
 
 blpAuthenticate <- function(uuid, host="localhost", ip.address, con=defaultConnection()) {
-    if (missing(ip.address)) {
-        ## Linux only ?
-        cmd.res <- system(paste("host",host), intern=TRUE,
-                          ignore.stdout=FALSE, ignore.stderr=FALSE,wait=TRUE)
-        ip.address <- strsplit(cmd.res,"address ")[[1]][2]
+    if(missing(uuid)) {
+        ## no UUID, assume BPIPE
+        authenticate_Impl(con, NULL, NULL)
+    } else {
+        ## have UUID, assume SAPI
+        if (missing(ip.address)) {
+            ## Linux only ?
+            cmd.res <- system(paste("host",host), intern=TRUE,
+                              ignore.stdout=FALSE, ignore.stderr=FALSE,wait=TRUE)
+            ip.address <- strsplit(cmd.res,"address ")[[1]][2]
+        }
+        authenticate_Impl(con, as.character(uuid), ip.address)
     }
-    authenticate_Impl(con, as.character(uuid), ip.address)
 }
-
-#### TODO: rename to just 'authenticate' ?
-
